"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BootstrapUtils = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const Handlebars = require("handlebars");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const yaml = require('js-yaml');
// eslint-disable-next-line @typescript-eslint/no-var-requires
class BootstrapUtils {
    static deleteFolderRecursive(folder) {
        if (fs_1.existsSync(folder)) {
            fs_1.readdirSync(folder).forEach((file) => {
                const curPath = path_1.join(folder, file);
                if (fs_1.lstatSync(curPath).isDirectory()) {
                    // recurse
                    this.deleteFolderRecursive(curPath);
                }
                else {
                    // delete file
                    fs_1.unlinkSync(curPath);
                }
            });
            fs_1.rmdirSync(folder);
        }
    }
    static loadPresetData(root, preset, customPresetFile) {
        const defaultPreset = yaml.safeLoad(fs_1.readFileSync(`${root}/presets/default.yml`, 'utf8'));
        const networkPreset = yaml.safeLoad(fs_1.readFileSync(`${root}/presets/${preset}/config.yml`, 'utf8'));
        let customPreset = {};
        if (customPresetFile) {
            customPreset = yaml.safeLoad(fs_1.readFileSync(customPresetFile, 'utf8'));
        }
        return Object.assign(Object.assign(Object.assign(Object.assign({}, defaultPreset), networkPreset), customPreset), { preset });
    }
    static loadExistingPresetData(target) {
        return yaml.safeLoad(fs_1.readFileSync(`${target}/config/preset.yml`, 'utf8'));
    }
    static toAmount(renderedText) {
        const numberAsString = (renderedText + '').split("'").join('');
        return (numberAsString.match(/\d{1,3}(?=(\d{3})*$)/g) || [numberAsString]).join("'");
    }
    static toHex(renderedText) {
        const numberAsString = renderedText
            .split("'")
            .join('')
            .replace(/^(0x\.)/, '');
        return '0x' + (numberAsString.match(/\w{1,4}(?=(\w{4})*$)/g) || [numberAsString]).join("'");
    }
    static removeUndefined(obj) {
        return Object.keys(obj).reduce((acc, key) => {
            return obj[key] !== undefined ? Object.assign(Object.assign({}, acc), { [key]: obj[key] }) : acc;
        }, {});
    }
    static async generateConfiguration(templateContext, copyFrom, copyTo) {
        // Loop through all the files in the config folder
        await fs_1.promises.mkdir(copyTo, { recursive: true });
        const files = await fs_1.promises.readdir(copyFrom);
        await Promise.all(files.map(async (file) => {
            const fromPath = path_1.join(copyFrom, file);
            const toPath = path_1.join(copyTo, file);
            // Stat the file to see if we have a file or dir
            const stat = await fs_1.promises.stat(fromPath);
            if (stat.isFile()) {
                if (toPath.indexOf('.mustache') > -1) {
                    const destinationFile = toPath.replace('.mustache', '');
                    const template = await fs_1.promises.readFile(fromPath, 'utf8');
                    Handlebars.registerHelper('toAmount', BootstrapUtils.toAmount);
                    Handlebars.registerHelper('toHex', BootstrapUtils.toHex);
                    const compiledTemplate = Handlebars.compile(template);
                    const renderedTemplate = compiledTemplate(Object.assign({}, templateContext));
                    await fs_1.promises.writeFile(destinationFile, renderedTemplate);
                }
                else {
                    await fs_1.promises.copyFile(fromPath, toPath);
                }
            }
            else if (stat.isDirectory()) {
                await fs_1.promises.mkdir(toPath, { recursive: true });
                await this.generateConfiguration(templateContext, fromPath, toPath);
            }
        }));
    }
    static async mkdir(path) {
        await fs_1.promises.mkdir(path, { recursive: true });
    }
    static async writeYaml(path, object) {
        const yamlString = yaml.safeDump(object, { skipInvalid: false, indent: 4, lineWidth: 140 });
        await fs_1.promises.writeFile(path, yamlString, 'utf8');
    }
}
exports.BootstrapUtils = BootstrapUtils;
