"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CertificateService = void 0;
const BootstrapUtils_1 = require("./BootstrapUtils");
const LoggerFactory_1 = require("../logger/LoggerFactory");
const LogType_1 = require("../logger/LogType");
// eslint-disable-next-line @typescript-eslint/no-var-requires
const util = require("util");
// eslint-disable-next-line @typescript-eslint/no-var-requires
// eslint-disable-next-line @typescript-eslint/no-var-requires
const exec = util.promisify(require('child_process').exec);
const logger = LoggerFactory_1.default.getLogger(LogType_1.LogType.System);
class CertificateService {
    constructor(params) {
        this.params = params;
    }
    getKey(stdout, from, to) {
        return stdout
            .substring(stdout.indexOf(from) + from.length, stdout.indexOf(to))
            .trim()
            .split(':')
            .map((m) => m.trim())
            .join('');
    }
    async run(name) {
        const presetData = BootstrapUtils_1.BootstrapUtils.loadPresetData(this.params.root, this.params.preset, this.params.presetFile);
        const copyFrom = `${this.params.root}/config/cert`;
        const target = `${this.params.target}/config/${name}/resources/cert`;
        const generatedContext = { name };
        const templateContext = Object.assign(Object.assign({}, presetData), generatedContext);
        await BootstrapUtils_1.BootstrapUtils.generateConfiguration(templateContext, copyFrom, target);
        //TODO migrate to forge
        const { stdout } = await exec(this.createCertCommands(target));
        const privateKey = this.getKey(stdout, 'priv:', 'pub:');
        const publicKey = this.getKey(stdout, 'pub:', 'Certificate:');
        // console.log('privateKey', privateKey);
        // console.log('publicKey', publicKey);
        // const privatePem = await fs.promises.readFile(`${target}/ca.key.pem`, 'utf8');
        // const publicPem = await fs.promises.readFile(`${target}/ca.pubkey.pem`, 'utf8');
        // console.log('privatePem', privatePem);
        // console.log('publicPem', publicPem);
        // const pki = forge.pki;
        // // const publicKey = pki.publicKeyFromPem(publicPem);
        // // console.log('publicKey', publicKey);
        //
        // const privateKey = pki.privateKeyFromPem(privatePem);
        // console.log('privateKey', privateKey);
        // await exec(`cd ${target} && cat node.crt.pem ca.cert.pem > node.full.crt.pem`);
        // const pki = forge.pki;
        // const ed25519 = forge.pki.ed25519;
        // const keypair = ed25519.generateKeyPair();
        // const pem = pki.privateKeyToPem(forge.asn1.fromDer(keypair.privateKey));
        // console.log(pem);
        return { privateKey, publicKey };
    }
    createCertCommands(target) {
        const commands = `
cd ${target}

mkdir new_certs && chmod 700 new_certs
touch index.txt

# create CA key
openssl genpkey -out ca.key.pem -outform PEM -algorithm ed25519
openssl pkey -inform pem -in ca.key.pem -text -noout
openssl pkey -in ca.key.pem -pubout -out ca.pubkey.pem

# create CA cert and self-sign it
openssl req -config ca.cnf -keyform PEM -key ca.key.pem -new -x509 -days 7300 -out ca.cert.pem
openssl x509 -in ca.cert.pem  -text -noout

# create node key
openssl genpkey -out node.key.pem -outform PEM -algorithm ed25519
openssl pkey -inform pem -in node.key.pem -text -noout

# create request
openssl req -config node.cnf -key node.key.pem -new -out node.csr.pem
openssl req  -text -noout -verify -in node.csr.pem

### below is done after files are written
# CA side
# create serial
openssl rand -hex 19 > ./serial.dat

# sign cert for 375 days
openssl ca -batch -config ca.cnf -days 375 -notext -in node.csr.pem -out node.crt.pem
openssl verify -CAfile ca.cert.pem node.crt.pem

# finally create full crt
cat node.crt.pem ca.cert.pem > node.full.crt.pem
`;
        return commands;
    }
}
exports.CertificateService = CertificateService;
