import { Account, NetworkType } from 'symbol-sdk';
export interface ConfigParams {
    root: string;
    reset: boolean;
    preset: string;
    target: string;
    presetFile?: string;
}
export interface MosaicPreset {
    name: string;
    divisibility: number;
    duration: number;
    supply: number;
    isTransferable: boolean;
    isSupplyMutable: boolean;
    isRestrictable: boolean;
    accounts: number;
    currencyDistributions: {
        address: string;
        amount: number;
    }[];
}
export interface DatabasePreset {
    name: string;
    openPort: boolean;
}
export declare enum NodeType {
    PEER_NODE = "peer-node",
    API_NODE = "api-node"
}
export interface ConfigPreset {
    nemgen: boolean;
    nemesisSignerPublicKey: string;
    nemesisGenerationHashSeed: string;
    transactionsDirectory: string;
    nodes?: any[];
    gateways?: any[];
    networkType: NetworkType;
    networkIdentifier: string;
    networkName: string;
    currencyMosaicId: string;
    harvestingMosaicId: string;
    nemesisSignerPrivateKey: string;
    binDirectory: string;
    baseNamespace: string;
    databases?: DatabasePreset[];
    mosaics?: MosaicPreset[];
    knownPeers?: Record<NodeType, any[]>;
}
export interface CertificatePair {
    privateKey: string;
    publicKey: string;
}
export interface ConfigAccount extends CertificatePair {
    address: string;
}
export interface NodeAccount {
    signing: ConfigAccount;
    ssl: CertificatePair;
    type: NodeType;
    vrf: ConfigAccount;
    name: string;
}
export interface ConfigAddresses {
    nodes?: NodeAccount[];
    gateways?: ConfigAccount[];
    nemesisGenerationHashSeed: string;
    nemesisSigner?: ConfigAccount;
    networkType: NetworkType;
    mosaics?: Record<string, ConfigAccount[]>;
}
export declare class ConfigService {
    private readonly params;
    static defaultParams: ConfigParams;
    constructor(params?: ConfigParams);
    toConfig(account: Account): ConfigAccount;
    static getNetworkIdentifier(networkType: NetworkType): string;
    static getNetworkName(networkType: NetworkType): string;
    generateAddresses(networkType: NetworkType, size: number): ConfigAccount[];
    generateNodeAccount(index: number, node: any, networkType: NetworkType): Promise<NodeAccount>;
    generateNodeAccounts(networkType: NetworkType, nodes: any[]): Promise<NodeAccount[]>;
    generateAddress(networkType: NetworkType): ConfigAccount;
    private static getArray;
    run(): Promise<void>;
    private completePresetDataWithRandomConfiguration;
    private generateRandomConfiguration;
    private generateNodes;
    private generateNodeConfiguration;
    private generateP2PFile;
    private generateNemesisConfig;
    private createVrfTransaction;
    private generategateways;
}
