"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunService = void 0;
const LoggerFactory_1 = require("../logger/LoggerFactory");
const LogType_1 = require("../logger/LogType");
const child_process_1 = require("child_process");
const logger = LoggerFactory_1.default.getLogger(LogType_1.LogType.System);
class RunService {
    constructor(params) {
        this.params = params;
    }
    async run() {
        const target = `${this.params.target}`;
        const dockerFile = `${target}/docker/docker-compose.yml`;
        const cmd = child_process_1.spawn('docker-compose', ['-f', dockerFile, 'up', '--build']);
        cmd.stdout.on('data', (data) => {
            console.log(`${data}`.trim());
        });
        cmd.stderr.on('data', (data) => {
            console.log(`${data}`.trim());
        });
        cmd.on('error', (error) => {
            console.log(`error: ${error.message}`.trim());
        });
        cmd.on('exit', (code, signal) => {
            console.log(`child process exited with code ${code} and signal ${signal}`);
        });
        cmd.on('close', (code) => {
            console.log(`child process exited with code ${code}`);
        });
        process.on('SIGINT', function () {
            console.log('Received SIGINT signal');
        });
        logger.info(`running docker-compose.yml ${dockerFile}`);
    }
}
exports.RunService = RunService;
